Command Line Interface — MzFont 0.0.1 documentation

# Command Line Interface

Sharp MZ TrueType font.

    usage: mzfont [-h] [-v] {make,default,test} ...

## Positional Arguments

`subcommand`

  Possible choices: make, default, test

## Named Arguments

`-v`

  show program’s version number and exit

## Sub-commands

### make

Generate TrueType font file.

    mzfont make [-h] [-b BASE] [-n NAME] CG MONITOR TTF

#### Positional Arguments

`CG`

  character rom file

`MONITOR`

  monitor rom file

`TTF`

  output file

#### Named Arguments

`-b`

  base font file

  Default: `'/usr/share/fonts/truetype/dejavu/DejaVuSansMono.ttf'`

`-n`

  font name

  Default: `'SharpMZ'`

### default

Generate TrueType font file and modify default font.

    mzfont default [-h] [-b BASE] [-n NAME] CG MONITOR TTF

#### Positional Arguments

`CG`

  character rom file

`MONITOR`

  monitor rom file

`TTF`

  output file

#### Named Arguments

`-b`

  base font file

  Default: `'/usr/share/fonts/truetype/dejavu/DejaVuSansMono.ttf'`

`-n`

  font name

  Default: `'SharpMZ'`

### test

Print all character sets.

    mzfont test [-h]

Copyright (c) 2025 by Jeroen F.J. Laros <jlaros@fixedpoint.nl>